==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandenlijstOpvragenRequest }
     * 
     */
    public BestandenlijstOpvragenRequest createBestandenlijstOpvragenRequest() {
        return new BestandenlijstOpvragenRequest();
    }

    /**
     * Create an instance of {@link BestandenlijstOpvragenResponse }
     * 
     */
    public BestandenlijstOpvragenResponse createBestandenlijstOpvragenResponse() {
        return new BestandenlijstOpvragenResponse();
    }

}

==> kadaster-gds2-2.7-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandenlijstOpvragenRequest }
     * 
     */
    public BestandenlijstOpvragenRequest createBestandenlijstOpvragenRequest() {
        return new BestandenlijstOpvragenRequest();
    }

    /**
     * Create an instance of {@link BestandenlijstOpvragenResponse }
     * 
     */
    public BestandenlijstOpvragenResponse createBestandenlijstOpvragenResponse() {
        return new BestandenlijstOpvragenResponse();
    }

}
